@@ -1,16 +1,13 @@
 """Library for working with MISP export files"""
 
 import enum
-import uuid
-import json
-import time
-import re
 import ipaddress
-
-from logging import error
-
-from typing import Optional, Text, Tuple, Dict, Callable
-
+import json
+import re
+import time
+import uuid
+from logging import warning
+from typing import Callable, Dict, Optional, Text, Tuple
 
 
 class ThreatLevelID(enum.Enum):
@@ -118,7 +115,11 @@ class Event:  # pylint: disable=R0902
             self.analysis = Analysis(int(event["analysis"]))
             self.date = event["date"]
             self.timestamp = event["timestamp"]
-            self.publish_timestamp = event["publish_timestamp"]
+
+            if "publish_timestamp" in event:
+                self.publish_timestamp = event["publish_timestamp"]
+            else:
+                warning("publish_timestamp missing in event %s", event)
             self.org_id = event.get("org_id", "N/A")
             self.orgc_id = event.get("orgc_id", "N/A")
             self.attribute_count = event.get("attribute_count", 0)
@@ -165,10 +166,7 @@ class Attribute:  # attributeattributes in misp babel pylint: disable=R0903
             self.act_type: Optional[Text] = None
             self.value: Optional[Text] = None
 
-            try:
-                self.act_type, self.value = mapper_fn(attributedict["value"])
-            except ValidationError as e:
-                error(str(e))
+            self.act_type, self.value = mapper_fn(attributedict["value"])
 
             if (
                 "RelatedAttribute" in attributedict
